<?php

namespace USCANADAMap_T;

class USCANADAMap_T
{
    const PLUGIN_NAME = 'US-Canada Map [Trial]';

    private $options = null;

    public function init()
    {
        $this->initActions();
        $this->initShortcodes();
        $this->initOptions();
    }

    private function initActions()
    {
        add_action('admin_menu', array($this, 'addOptionsPage'));
        add_action('admin_footer', array($this, 'addJsConfigInFooter'));
        add_action('wp_footer', array($this, 'addSpanTag'));
        add_action('admin_enqueue_scripts', array($this, 'initAdminScript'));
    }

    private function initShortcodes()
    {
        add_shortcode('uscanada_map_t', array($this, 'USCANADAMap_TShortcode'));
    }

    private function initOptions()
    {
        $defaultOptions = $this->getDefaultOptions();
        $this->options  = get_option('uscanada_map_t');

        $this->updateOptions($defaultOptions);

        if (!is_array($this->options)) {
            $this->options = $defaultOptions;
        }

        $this->prepareOptionsListForTpl();
    }

    public function addJsConfigInFooter()
    {
        include __DIR__ . "/../includes/js-config-admin-footer.php";
    }

    public function addOptionsPage()
    {
        add_menu_page(
            USCANADAMap_T::PLUGIN_NAME,
            USCANADAMap_T::PLUGIN_NAME,
            'manage_options',
            'uscanada-map-t',
            array($this, 'optionsScreen'),
            USCANADAMAP_T_URL . 'public/images/map-icon.png'
        );
    }

    /**
     * @return array
     */
    private function getDefaultOptions()
    {
        $default = array(
            'uscanadabrdrclr_t'   => '#6B8B9E',
            'uscanadavisns_t'     => '#666666',
            'uscanadalakesfill_t' => '#66CCFF',
            'uscanadalakesout_t'  => '#6B8B9E',
        );

        $areas = array(
            'ALBERTA', 'BRITISH COLUMBIA', 'MANITOBA', 'ALABAMA', 'ALASKA', 'ARIZONA', 'ARKANSAS', 'CALIFORNIA', 'COLORADO', 'CONNECTICUT', 'DELAWARE', 'FLORIDA', 'GEORGIA', 'HAWAII', 'IDAHO', 'ILLINOIS', 'INDIANA', 'IOWA', 'KANSAS', 'KENTUCKY', 'LOUISIANA', 'MAINE', 'MARYLAND', 'MASSACHUSETTS'
        );

        foreach ($areas as $k => $area) {
            $default['upclr_' . ($k + 1)]  = '#E0F3FF';
            $default['ovrclr_' . ($k + 1)] = '#8FBEE8';
            $default['dwnclr_' . ($k + 1)] = '#477CB2';
            $default['url_' . ($k + 1)]    = '';
            $default['turl_' . ($k + 1)]   = '_self';
            $default['info_' . ($k + 1)]   = $area;
            $default['enbl_' . ($k + 1)]   = 1;
        }

        return $default;
    }

    private function updateOptions(array $defaultOptions)
    {
        if (isset($_POST['uscanada_map_t']) && isset($_POST['submit-clrs'])) {
            $i = 1;
            while (isset($_POST['url_' . $i])) {
                $_POST['upclr_' . $i]  = $_POST['upclr_all'];
                $_POST['ovrclr_' . $i] = $_POST['ovrclr_all'];
                $_POST['dwnclr_' . $i] = $_POST['dwnclr_all'];

                $i++;
            }

            update_option('uscanada_map_t', array_map(array($this, 'stripslashesDeep'), $_POST));

            $this->options = array_map(array($this, 'stripslashesDeep'), $_POST);
        }

        if (isset($_POST['uscanada_map_t']) && isset($_POST['submit-url'])) {
            $i = 1;
            while (isset($_POST['url_' . $i])) {
                $_POST['url_' . $i]  = $_POST['url_all'];
                $_POST['turl_' . $i] = $_POST['turl_all'];

                $i++;
            }

            update_option('uscanada_map_t', array_map(array($this, 'stripslashesDeep'), $_POST));

            $this->options = array_map(array($this, 'stripslashesDeep'), $_POST);
        }

        if (isset($_POST['uscanada_map_t']) && isset($_POST['submit-info'])) {
            $i = 1;
            while (isset($_POST['url_' . $i])) {
                $_POST['info_' . $i] = $_POST['info_all'];

                $i++;
            }

            update_option('uscanada_map_t', array_map(array($this, 'stripslashesDeep'), $_POST));

            $this->options = array_map(array($this, 'stripslashesDeep'), $_POST);
        }

        if (isset($_POST['uscanada_map_t']) && !isset($_POST['preview_map'])) {
            update_option('uscanada_map_t', array_map(array($this, 'stripslashesDeep'), $_POST));

            $this->options = array_map(array($this, 'stripslashesDeep'), $_POST);
        }

        if (isset($_POST['uscanada_map_t']) && isset($_POST['restore_default'])) {
            update_option('uscanada_map_t', $defaultOptions);

            $this->options = $defaultOptions;
        }
    }

    private function prepareOptionsListForTpl()
    {
        $this->options['prepared_list'] = array();
        $i                              = 1;
        while (isset($this->options['url_' . $i])) {
            $this->options['prepared_list'][] = array(
                'index' => $i,
                'info_' => str_replace(
                    array("\n", "\r", "\r\n"),
                    '',
                    is_array($this->options['info_' . $i]) ? array_map(array($this, 'stripslashesDeep'), $this->options['info_' . $i]) : stripslashes($this->options['info_' . $i])
                ),
                'url'    => $this->options['url_' . $i],
                'turl'   => $this->options['turl_' . $i],
                'upclr'  => $this->options['upclr_' . $i],
                'ovrclr' => $this->options['ovrclr_' . $i],
                'dwnclr' => $this->options['dwnclr_' . $i],
                'enbl'   => $this->options['enbl_' . $i] == '1',
            );

            $i++;
        }
    }

    public function USCANADAMap_TShortcode()
    {
        wp_enqueue_style('uscanada-map-t-style-frontend', USCANADAMAP_T_URL . 'public/css/map-style.css', false, '1.0', 'all');
        wp_enqueue_script('uscanada-map-t-interact', USCANADAMAP_T_URL . 'public/js/map-interact.js', array('jquery'), 10, '1.0', true);

        ob_start();

        include __DIR__ . "/../includes/map.php";
        include __DIR__ . "/../includes/js-config-footer.php";

        return ob_get_clean();
    }

    public function optionsScreen()
    {
        include __DIR__ . "/../includes/admin.php";
    }

    public function initAdminScript()
    {
        if (isset($_GET['page']) && $_GET['page'] == 'uscanada-map-t'):
            wp_enqueue_style('wp-color-picker');
            wp_enqueue_style('thickbox');
            wp_enqueue_script('thickbox');
            wp_enqueue_script('media-upload');

            wp_enqueue_style('uscanada-map-t-dashboard-style', USCANADAMAP_T_URL . 'public/css/dashboard-style.css', false, '1.0', 'all');
            wp_enqueue_style('uscanada-map-t-style', USCANADAMAP_T_URL . 'public/css/map-style.css', false, '1.0', 'all');
            wp_enqueue_style('wp-tinyeditor', USCANADAMAP_T_URL . 'public/css/tinyeditor.css', false, '1.0', 'all');

            wp_enqueue_script('uscanada-map-t-interact', USCANADAMAP_T_URL . 'public/js/map-interact.js?t=' . time(), array('jquery'), 10, '1.0', true);
            wp_enqueue_script('uscanada-map-t-tiny.editor', USCANADAMAP_T_URL . 'public/js/editor/tinymce.min.js', 10, '1.0', true);
            wp_enqueue_script('uscanada-map-t-script', USCANADAMAP_T_URL . 'public/js/editor/scripts.js', array('wp-color-picker'), false, true);
        endif;
    }

    public function addSpanTag()
    {
        echo '<span id="tipuscanadamap-t"></span>';
    }

    public function stripslashesDeep($value)
    {
        return is_array($value) ?
            array_map(array($this, 'stripslashesDeep'), $value) : stripslashes($value);
    }
}
